#[repr(transparent)]pub struct Inten(pub u32);Expand description
PUF Interrupt Enable
Tuple Fields
0: u32Implementations
Sourceimpl Inten
impl Inten
Sourcepub const fn readyen(&self) -> bool
pub const fn readyen(&self) -> bool
Enable corresponding interrupt. Note that bit numbers match those assigned in QK_SR (Quiddikey Status Register)
Sourcepub const fn set_readyen(&mut self, val: bool)
pub const fn set_readyen(&mut self, val: bool)
Enable corresponding interrupt. Note that bit numbers match those assigned in QK_SR (Quiddikey Status Register)
Sourcepub const fn succesen(&self) -> bool
pub const fn succesen(&self) -> bool
Enable corresponding interrupt. Note that bit numbers match those assigned in QK_SR (Quiddikey Status Register)
Sourcepub const fn set_succesen(&mut self, val: bool)
pub const fn set_succesen(&mut self, val: bool)
Enable corresponding interrupt. Note that bit numbers match those assigned in QK_SR (Quiddikey Status Register)
Sourcepub const fn erroren(&self) -> bool
pub const fn erroren(&self) -> bool
Enable corresponding interrupt. Note that bit numbers match those assigned in QK_SR (Quiddikey Status Register)
Sourcepub const fn set_erroren(&mut self, val: bool)
pub const fn set_erroren(&mut self, val: bool)
Enable corresponding interrupt. Note that bit numbers match those assigned in QK_SR (Quiddikey Status Register)
Sourcepub const fn keyinreqen(&self) -> bool
pub const fn keyinreqen(&self) -> bool
Enable corresponding interrupt. Note that bit numbers match those assigned in QK_SR (Quiddikey Status Register)
Sourcepub const fn set_keyinreqen(&mut self, val: bool)
pub const fn set_keyinreqen(&mut self, val: bool)
Enable corresponding interrupt. Note that bit numbers match those assigned in QK_SR (Quiddikey Status Register)
Sourcepub const fn keyoutavailen(&self) -> bool
pub const fn keyoutavailen(&self) -> bool
Enable corresponding interrupt. Note that bit numbers match those assigned in QK_SR (Quiddikey Status Register)
Sourcepub const fn set_keyoutavailen(&mut self, val: bool)
pub const fn set_keyoutavailen(&mut self, val: bool)
Enable corresponding interrupt. Note that bit numbers match those assigned in QK_SR (Quiddikey Status Register)
Sourcepub const fn codeinreqen(&self) -> bool
pub const fn codeinreqen(&self) -> bool
Enable corresponding interrupt. Note that bit numbers match those assigned in QK_SR (Quiddikey Status Register)
Sourcepub const fn set_codeinreqen(&mut self, val: bool)
pub const fn set_codeinreqen(&mut self, val: bool)
Enable corresponding interrupt. Note that bit numbers match those assigned in QK_SR (Quiddikey Status Register)
Sourcepub const fn codeoutavailen(&self) -> bool
pub const fn codeoutavailen(&self) -> bool
Enable corresponding interrupt. Note that bit numbers match those assigned in QK_SR (Quiddikey Status Register)
Sourcepub const fn set_codeoutavailen(&mut self, val: bool)
pub const fn set_codeoutavailen(&mut self, val: bool)
Enable corresponding interrupt. Note that bit numbers match those assigned in QK_SR (Quiddikey Status Register)