nxp-pac

Crates

git

Versions

lpc55s69_cm33_core0

Flavors

Keyoutindex

Struct Keyoutindex 

#[repr(transparent)]
pub struct Keyoutindex(pub u32);
PUF Key Output Index register

Tuple Fields

0: u32

Implementations

Source

impl Keyoutindex

pub const fn keyoutidx(&self) -> u8

Key index for the key that is currently output via the Key Output register

pub const fn set_keyoutidx(&mut self, val: u8)

Key index for the key that is currently output via the Key Output register